@@ -7,7 +7,8 @@
 #pragma once
 
 #include "PackageKitResource.h"
-#include <AppStreamQt/pool.h>
+
+#include <PackageKit/Offline>
 #include <PackageKit/Transaction>
 #include <QFile>
 #include <QPointer>
@@ -17,6 +18,8 @@
 #include <QThreadPool>
 #include <QTimer>
 #include <QVariantList>
+
+#include <appstream/AppStreamConcurrentPool.h>
 #include <resources/AbstractResourcesBackend.h>
 
 class AppPackageKitResource;
@@ -87,7 +90,6 @@ public:
         return !QFile::exists(QStringLiteral("/run/ostree-booted"));
     }
     QSet<AbstractResource *> upgradeablePackages() const;
-    bool isFetching() const override;
 
     bool isPackageNameUpgradeable(const PackageKitResource *res) const;
     QSet<QString> upgradeablePackageId(const PackageKitResource *res) const;
@@ -130,6 +132,15 @@ public:
     {
         return m_globalHints;
     }
+    void aboutTo(AboutToAction action) override;
+    bool needsRebootForPowerOffAction() const override
+    {
+        return true;
+    }
+    QPointer<PackageKit::Transaction> refresher() const
+    {
+        return m_refresher;
+    }
 
 public Q_SLOTS:
     void reloadPackageList();
@@ -168,7 +179,8 @@ private:
     void updateProxy();
     void foundNewMajorVersion(const AppStream::Release &release);
 
-    QScopedPointer<AppStream::Pool> m_appdata;
+    QScopedPointer<AppStream::ConcurrentPool> m_appdata;
+    bool m_appdataLoaded = false;
     PackageKitUpdater *m_updater;
     QPointer<PackageKit::Transaction> m_refresher;
     int m_isFetching;
@@ -190,4 +202,5 @@ private:
     QPointer<PKResolveTransaction> m_resolveTransaction;
     QStringList m_globalHints;
     bool m_allPackagesLoaded = false;
+    DiscoverAction *m_reportToDistroAction;
 };
